@@ -92,13 +92,18 @@ def compare_cmd(args,
         p = make_parse_obj(args)
     else:
         p = parse_obj
-    n_changed, n_unchanged = compare(p,
+    revision = None if args.compare == '' else args.compare
+    try:
+        n_changed, n_unchanged = compare(p,
                                  facet=args.use,
                                  ask=args.ask,
-                                 revision_specifier=args.compare,
+                                 revision_specifier=revision,
                                  flip=args.flip,
                                  logger=p.logger
                                  )
+    except TypeError:
+        logger.error(f"No files to compare. Try adding the flag -a to parse files even if they are not included in a metdata.tsv file.")
+        return
     logger.debug(f"{n_changed} files changed labels during comparison, {n_unchanged} didn't.")
     if output:
         corpus2paths = store_scores(p,
@@ -215,17 +220,18 @@ def metadata(args, parse_obj: Optional[Parse] = None):
 
 
 def transform(args, parse_obj: Optional[Parse] = None):
-    suffixes = make_suffixes(args, include_metadata=True)
-    if parse_obj is None:
-        p = make_parse_obj(args, parse_tsv=True)
-    else:
-        p = parse_obj
+    logger = get_logger('ms3.transform', level=args.level)
     params = gather_extract_params(args)
-    print(params)
     if len(params) == 0:
         print(
             "Pass at least one of the following arguments: -M (measures), -N (notes), -R (rests), -L (labels), -X (expanded), -F (form_labels), -E (events), -C (chords), -D (metadata)")
         return
+    suffixes = make_suffixes(args, include_metadata=True)
+    if parse_obj is None:
+        p = make_parse_obj(args, parse_tsv=True, facets=params)
+    else:
+        p = parse_obj
+
 
     for param in params:
         sfx = suffixes.get(f"{param}_suffix", '')
@@ -239,11 +245,14 @@ def transform(args, parse_obj: Optional[Parse] = None):
         else:
             df = p.get_facets(param, flat=True, interval_index=args.interval_index, unfold=args.unfold)
         df = df.reset_index(drop=False)
+        if df is None or len(df.index) == 0:
+            logger.info(f"No {param} data found. Maybe you haven't run ms3 extract?")
+            continue
         if args.test:
-            p.logger.info(f"Would have written {path}.")
+            logger.info(f"Would have written {path}.")
         else:
             write_tsv(df, path)
-            p.logger.info(f"{path} written.")
+            logger.info(f"{path} written.")
 
 
 def update_cmd(args, parse_obj: Optional[Parse] = None):
@@ -390,7 +399,7 @@ def review_cmd(args,
 
 
 
-def make_parse_obj(args, parse_scores=False, parse_tsv=False):
+def make_parse_obj(args, parse_scores=False, parse_tsv=False, facets=None):
     labels_cfg = {}
     if hasattr(args, 'positioning'):
         labels_cfg['positioning'] = args.positioning
@@ -432,11 +441,15 @@ Parse('{args.dir}',
                       labels_cfg=labels_cfg,
                       ms=ms,
                       **logger_cfg)
+    if facets is not None:
+        facets = [f for f in facets if f != 'metadata']
+        if len(facets) > 0:
+            parse_obj.view.include('facets', *facets)
     if parse_scores:
         mode = "ONE AFTER THE OTHER" if args.iterative else "IN PARALLEL"
         print(f"PARSING SCORES {mode}...")
         parse_obj.parse_scores(parallel=not args.iterative)
-    if parse_tsv:
+    if parse_tsv and facets != []:
         print(f"PARSING TSV FILES...")
         parse_obj.parse_tsv()
     info_str = parse_obj.info(show_discarded=args.verbose, return_str=True).replace('\n', '\n\t')
